import {useState, useEffect} from 'react';

export function useFetchAvailableServers() {
    const [servers, setServers] = useState([]);
    const [error, setError] = useState(null);
    const [isLoading, setIsLoading] = useState(false);

    useEffect(() => {
        let isMounted = true;
        setIsLoading(true);

        fetch('app/api/available-servers')
            .then((response) => {
                if (!response.ok) {
                    throw new Error('Failed to fetch servers');
                }
                return response.json();
            })
            .then((data) => {
                setServers(data);
            })
            .catch((err) => {
                if (isMounted) {
                    setError(err.message);
                }
            })
            .finally(() => {
                if (isMounted) {
                    setIsLoading(false);
                }
            });

        return () => {
            isMounted = false; // Cleanup function to prevent state updates on unmounted component
        };
    }, []);

    return {
        error,
        servers,
        isLoading,
    }
}
