#!/usr/bin/env bash
set -x # echo on

PROJECT=rtls-centralized-sitewise

RPM_DESCRIPTION="Redpoint Positioning RTLS Centralized Sitewise Service"
RPM_MAINTAINER=help@redpointpositioning.com
RPP_VENDOR="Redpoint Positioning, Inc."

PROJECT_HOME=${WORKSPACE}

export PATH=/usr/local/bin:/usr/local/rbenv/shims:$PATH

VERSION="$( devops/sys-services/rtls-get-version.sh )"
RELEASE="$( devops/sys-services/rtls-get-release.sh )"
FILE="$( devops/sys-services/rtls-get-file-name.sh )"

echo "PROJECT_HOME:       ${PROJECT_HOME}"
echo "BUILDING ON BRANCH: ${BRANCH_NAME}"
echo "VERSION:            ${VERSION}"
echo "RELEASE:            ${RELEASE}"
echo "FILE:               ${FILE}"

# Clean previous builds
rm -f "${PROJECT_HOME}"/*.deb
[ -d "${PROJECT_HOME}"/releases ] && rm -f "${PROJECT_HOME}"/releases/*

# Navigate to the application directory
cd "${PROJECT_HOME}/apps/rtls-sitewise-portal"

# Install dependencies and build the project
npm install
npm run build
cp -r public .next/standalone/ && cp -r .next/static .next/standalone/.next/

# Return to the root project directory
cd "${PROJECT_HOME}"

# Build the DEB package
fpm -s dir -t deb -f \
  --description "${RPM_DESCRIPTION}" \
  --maintainer "${RPM_MAINTAINER}" \
  --vendor "${RPP_VENDOR}" \
  --license "Proprietary" \
  --provides "rtls-centralized-sitewise" \
  --exclude ".git" \
  --exclude "**/npm-cache" \
  --exclude "apps/rtls-sitewise-portal/node_modules" \
  --prefix /usr/rtls/rtls-centralized-sitewise \
  --rpm-use-file-permissions \
  --before-remove devops/sys-services/pre-uninstall.sh \
  --before-install devops/sys-services/pre-install.sh \
  --after-install devops/sys-services/post-install.sh \
  --before-upgrade devops/sys-services/pre-update.sh \
  --after-upgrade devops/sys-services/post-update.sh \
  --post-uninstall devops/sys-services/post-uninstall.sh \
  --deb-group rtls \
  --deb-user rtls \
  --name "${PROJECT}" \
  --version "${VERSION}" \
  --iteration "${RELEASE}" \
  --package "${PROJECT_HOME}" \
  .
